/*
 * File         : BV_Member.h
 * Author       : Tomasz Stachowiak
 * Created      : Thu May 21 19:34:58 1998
 * Revision     : $Revision$
 * Updated      : $Date$
 * Copyright: Northeast Parallel Architectures Center
 *            at Syracuse University 1998
 */

#ifndef __BV_MEMBER_H
#define __BV_MEMBER_H

#include <stdlib.h>
#include <semaphore.h>

#include <BVN/Message.h>
#include <BVN/SOCK_Stream.h>
#include <BVN/Reactor.h>

#include "BV_Msg_Header.h"
#include "BV_Message.h"
#include "BV.h"
#include "rtp.h"
#include "UserData.h"
#include "DisplayWindowMainWindow.h"

typedef unsigned char uchar;

class BV_Member
{
 public:
 
  BV_Member();
  BV_Member(SOCK_Stream *stream, int id, char *name, int host);
  BV_Member(char *name, int host);
  BV_Member(BV_Member *mbr);
  void operator= (BV_Member &mbr);
  ~BV_Member();

  int connect(Reactor *reactor);
  void close();
  int get_id(void);
  void set_id(int id);
  void set_name(char *name);
  void get_name(char *name);
  int get_host(void);
  int get_string(char *str);
  int get_participant(Participant *part);
  SOCK_Stream *get_stream();
  void set_stream(SOCK_Stream *stream);
  void set_internal_id(int internal_id);
  int get_internal_id();
  void update_audio_stat(RTPheader *header, int size);
  void update_video_stat(RTPheader *header, int size);
  UserData *get_audio_data();
  UserData *get_video_data();

  int send_msg(BV_Message *msg);

  int open_display();
  void close_display();
  void show_display();
  void hide_display();
  int display(char *frame);

  void open_dpy_req();
  void close_dpy_req();
  void display_req(char *frame);
  int handle_events();

  DisplayWindowMainWindow *dpy_win;
  int display_on_;

 private:
  
  int id_;
  char name_[20];
  int host_;
  int internal_id_;

  UserData *audio_data_;
  UserData *video_data_;

  SOCK_Stream *stream_;

  int open_dpy_;
  int init_dpy_;
  int close_dpy_;
  int display_;
  char frame_[176*144*3/2];
  sem_t sem_;

};



#endif

